@@ -9,9 +9,9 @@ Check these declarations against the C/Fortran source code.
 
 /* .Call calls */
 extern SEXP officer_a_ppr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP officer_a_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP officer_a_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP officer_css_ppr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP officer_css_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP officer_css_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP officer_p_ph(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP officer_pml_run_pic(SEXP, SEXP, SEXP);
 extern SEXP officer_pml_table(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -20,15 +20,15 @@ extern SEXP officer_rpr_new(SEXP);
 extern SEXP officer_rpr_p(SEXP);
 extern SEXP officer_rpr_w(SEXP);
 extern SEXP officer_w_ppr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP officer_w_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP officer_w_tcpr(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP officer_wml_run_pic(SEXP, SEXP, SEXP);
 extern SEXP officer_wml_table(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
   {"officer_a_ppr",       (DL_FUNC) &officer_a_ppr,       15},
-  {"officer_a_tcpr",      (DL_FUNC) &officer_a_tcpr,      21},
+  {"officer_a_tcpr",      (DL_FUNC) &officer_a_tcpr,      19},
   {"officer_css_ppr",     (DL_FUNC) &officer_css_ppr,     15},
-  {"officer_css_tcpr",    (DL_FUNC) &officer_css_tcpr,    21},
+  {"officer_css_tcpr",    (DL_FUNC) &officer_css_tcpr,    19},
   {"officer_p_ph",        (DL_FUNC) &officer_p_ph,         9},
   {"officer_pml_run_pic", (DL_FUNC) &officer_pml_run_pic,  3},
   {"officer_pml_table",   (DL_FUNC) &officer_pml_table,    8},
@@ -37,7 +37,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"officer_rpr_p",       (DL_FUNC) &officer_rpr_p,        1},
   {"officer_rpr_w",       (DL_FUNC) &officer_rpr_w,        1},
   {"officer_w_ppr",       (DL_FUNC) &officer_w_ppr,       15},
-  {"officer_w_tcpr",      (DL_FUNC) &officer_w_tcpr,      21},
+  {"officer_w_tcpr",      (DL_FUNC) &officer_w_tcpr,      19},
   {"officer_wml_run_pic", (DL_FUNC) &officer_wml_run_pic,  3},
   {"officer_wml_table",   (DL_FUNC) &officer_wml_table,    8},
   {NULL, NULL, 0}
